@@ -21,26 +21,25 @@ test_that("Recursive Tests ", {
   # recursive 1 - single / recipe / parsnip ----
 
   # Lag Recipe
-  recipe_lag <- recipe(value ~ date, m750_extended) %>%
+  recipe_lag <- recipes::recipe(value ~ date, m750_extended) %>%
     step_lag(value, lag = 1:FORECAST_HORIZON)
 
   # Data Transformation
   m750_lagged <- recipe_lag %>% prep() %>% juice()
 
-  train_data <- m750_lagged %>%
-    drop_na()
+  train_data <- tidyr::drop_na(m750_lagged)
 
   future_data <- m750_lagged %>%
-    filter(is.na(value))
+    dplyr::filter(is.na(value))
 
 
   # * Recursive Modeling ----
   model_fit_lm <- linear_reg() %>%
-    set_engine("lm") %>%
+    parsnip::set_engine("lm") %>%
     fit(value ~ date, data = train_data)
 
   model_fit_lm_recursive <- linear_reg() %>%
-    set_engine("lm") %>%
+    parsnip::set_engine("lm") %>%
     fit(value ~ ., data = train_data) %>%
     recursive(
       transform  = recipe_lag,
@@ -63,7 +62,7 @@ test_that("Recursive Tests ", {
   # Visualize
   # forecast_tbl %>% plot_modeltime_forecast()
 
-  preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+  preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
   expect_equal(
     length(future_data$value),
     length(preds)
@@ -92,7 +91,7 @@ test_that("Recursive Tests ", {
 
   # forecast_refit_tbl %>% plot_modeltime_forecast()
 
-  preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+  preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
   expect_equal(
     length(future_tbl$value),
     length(preds)
@@ -118,23 +117,22 @@ test_that("Recursive Tests ", {
   # Data Preparation
   m750_lagged <- m750_extended %>%
     lag_transformer() %>%
-    select(-id)
+    dplyr::select(-id)
 
-  train_data <- m750_lagged %>%
-    drop_na()
+  train_data <- tidyr::drop_na(m750_lagged)
 
   future_data <- m750_lagged %>%
-    filter(is.na(value))
+    dplyr::filter(is.na(value))
 
   # * Recursive Modeling ----
-  wflw_fit_lm <- workflow() %>%
-    add_recipe(recipe(value ~ date, train_data)) %>%
-    add_model(linear_reg() %>% set_engine("lm")) %>%
+  wflw_fit_lm <- workflows::workflow() %>%
+    workflows::add_recipe(recipes::recipe(value ~ date, train_data)) %>%
+    workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
     fit(train_data)
 
-  wflw_fit_lm_recursive <- workflow() %>%
-    add_recipe(recipe(value ~ ., train_data)) %>%
-    add_model(linear_reg() %>% set_engine("lm")) %>%
+  wflw_fit_lm_recursive <- workflows::workflow() %>%
+    workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+    workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
     fit(train_data) %>%
     recursive(
       transform  = lag_transformer,
@@ -156,7 +154,7 @@ test_that("Recursive Tests ", {
 
   # forecast_tbl %>% plot_modeltime_forecast()
 
-  preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+  preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
   expect_equal(
     length(future_data$value),
     length(preds)
@@ -187,7 +185,7 @@ test_that("Recursive Tests ", {
 
   # forecast_refit_tbl %>% plot_modeltime_forecast()
 
-  preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+  preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
   expect_equal(
     length(future_tbl$value),
     length(preds)
@@ -202,40 +200,39 @@ test_that("Recursive Tests ", {
   # recursive 3 - panel / function / parsnip + workflow
 
   # Jumble the data to make sure it forecasts properly
-  m4_monthly_updated <- m4_monthly %>%
-    arrange(desc(id), date) %>%
-    mutate(id = as_factor(as.character(id)))
+  m4_monthly_updated <- timetk::m4_monthly %>%
+    dplyr::arrange(desc(id), date) %>%
+    dplyr::mutate(id = forcats::as_factor(as.character(id)))
 
   m4_extended <- m4_monthly_updated %>%
-    group_by(id) %>%
-    future_frame(
+    dplyr::group_by(id) %>%
+    timetk::future_frame(
       .length_out = FORECAST_HORIZON,
       .bind_data  = TRUE
     ) %>%
-    ungroup()
+    dplyr::ungroup()
 
   # Transformation Function
   lag_transformer_grouped <- function(data){
     data %>%
-      group_by(id) %>%
+      dplyr::group_by(id) %>%
       # Lags
-      tk_augment_lags(value, .lags = 1:FORECAST_HORIZON) %>%
-      ungroup()
+      timetk::tk_augment_lags(value, .lags = 1:FORECAST_HORIZON) %>%
+      dplyr::ungroup()
   }
 
   m4_lags <- m4_extended %>%
     lag_transformer_grouped()
 
-  train_data <- m4_lags %>%
-    drop_na()
+  train_data <- drop_na(m4_lags)
 
   future_data <- m4_lags %>%
-    filter(is.na(value))
+    dplyr::filter(is.na(value))
 
   # * Recursive Modeling ----
 
   model_fit_lm_recursive <- linear_reg() %>%
-    set_engine("lm") %>%
+    parsnip::set_engine("lm") %>%
     fit(value ~ ., data = train_data) %>%
     recursive(
       id         = "id",
@@ -243,9 +240,9 @@ test_that("Recursive Tests ", {
       train_tail = panel_tail(train_data, id, FORECAST_HORIZON)
     )
 
-  wflw_fit_lm_recursive <- workflow() %>%
-    add_recipe(recipe(value ~ ., train_data)) %>%
-    add_model(linear_reg() %>% set_engine("lm")) %>%
+  wflw_fit_lm_recursive <- workflows::workflow() %>%
+    workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+    workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
     fit(train_data) %>%
     recursive(
       id         = "id",
@@ -265,13 +262,13 @@ test_that("Recursive Tests ", {
   ) %>%
     modeltime_forecast(
       new_data    = future_data,
-      actual_data = m4_monthly,
+      actual_data = timetk::m4_monthly,
       keep_data   = TRUE
     )
 
   # forecast_tbl %>% group_by(id) %>% plot_modeltime_forecast()
-  preds_1 <- forecast_tbl %>% filter(.model_id == 1) %>% pull(.value)
-  preds_2 <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+  preds_1 <- forecast_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+  preds_2 <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
   expect_equal(
     length(future_data$value),
     length(preds_1),
@@ -316,8 +313,8 @@ test_that("Recursive Tests ", {
 
   # forecast_refit_tbl %>% group_by(id) %>% plot_modeltime_forecast()
 
-  preds_1 <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
-  preds_2 <- forecast_refit_tbl %>% filter(.model_id == 2) %>% pull(.value)
+  preds_1 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+  preds_2 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
 
   expect_equal(
     length(future_tbl$value),
